@@ -67,9 +67,9 @@ void scoresWidget::paintEvent(QPaintEvent *)
 	
 	p.setPen(Qt::black);
 	
-	if (blinkenSettings::customFont()) f = QFont("Steve");
+	if (blinkenSettings::customFont()) f = QFont(QStringLiteral("Steve"));
 	p.setFont(f);
-	f.setPointSize(KFontUtils::adaptFontSize(p, "A", 1000, namesFontSize, 28, 1, KFontUtils::DoNotAllowWordWrap));
+	f.setPointSize(KFontUtils::adaptFontSize(p, QStringLiteral("A"), 1000, namesFontSize, 28, 1, KFontUtils::DoNotAllowWordWrap));
 	p.setFont(f);
 	
 	p.translate(margin, margin);
@@ -96,9 +96,9 @@ QSize scoresWidget::calcSize()
 	QPainter p(&dummyPixmap);
 	QFont f;
 	
-	if (blinkenSettings::customFont()) f = QFont("Steve");
+	if (blinkenSettings::customFont()) f = QFont(QStringLiteral("Steve"));
 	p.setFont(f);
-	f.setPointSize(KFontUtils::adaptFontSize(p, "A", 1000, namesFontSize, 28, 1, KFontUtils::DoNotAllowWordWrap));
+	f.setPointSize(KFontUtils::adaptFontSize(p, QStringLiteral("A"), 1000, namesFontSize, 28, 1, KFontUtils::DoNotAllowWordWrap));
 	p.setFont(f);
 	for (int i = 0; i < 3; i++)
 	{
@@ -149,9 +149,9 @@ highScoreDialog::highScoreDialog(QWidget *parent, QSvgRenderer *renderer) : QDia
 
 	highScoreManager hsm;
 	
-	m_tw -> addTab(new scoresWidget(0, hsm.scores(0), renderer), i18nc("@title:group High scores Level 1 tab title", "Level 1"));
-	m_tw -> addTab(new scoresWidget(0, hsm.scores(1), renderer), i18nc("@title:group High scores Level 2 tab title", "Level 2"));
-	m_tw -> addTab(new scoresWidget(0, hsm.scores(2), renderer), i18nc("@title:group High scores Level ? tab tible", "Level ?"));
+	m_tw -> addTab(new scoresWidget(nullptr, hsm.scores(0), renderer), i18nc("@title:group High scores Level 1 tab title", "Level 1"));
+	m_tw -> addTab(new scoresWidget(nullptr, hsm.scores(1), renderer), i18nc("@title:group High scores Level 2 tab title", "Level 2"));
+	m_tw -> addTab(new scoresWidget(nullptr, hsm.scores(2), renderer), i18nc("@title:group High scores Level ? tab tible", "Level ?"));
 }
 
 void highScoreDialog::showLevel(int level)
@@ -207,12 +207,12 @@ void highScoreManager::addScore(int level, int score, const QString &name)
 		m_scores[level].insert(it, qMakePair(score, name));
 		m_scores[level].erase(--m_scores[level].end());
 		
-		KConfigGroup cfg(KSharedConfig::openConfig(), QString("Level%1").arg(level + 1));
+		KConfigGroup cfg(KSharedConfig::openConfig(), QStringLiteral("Level%1").arg(level + 1));
 		int j;
 		for (it = m_scores[level].begin(), j = 1; it != m_scores[level].end(); ++it, j++)
 		{
-			cfg.writeEntry(QString("Score%1").arg(j), (*it).first);
-			cfg.writeEntry(QString("Name%1").arg(j), (*it).second);
+			cfg.writeEntry(QStringLiteral("Score%1").arg(j), (*it).first);
+			cfg.writeEntry(QStringLiteral("Name%1").arg(j), (*it).second);
 		}
 		cfg.sync();
 
@@ -234,10 +234,10 @@ void highScoreManager::update()
 	}
 	for (int i = 1; i <= 3; i++)
 	{
-		KConfigGroup cfg(KSharedConfig::openConfig(), QString("Level%1").arg(i));
+		KConfigGroup cfg(KSharedConfig::openConfig(), QStringLiteral("Level%1").arg(i));
 		for (int j = 1; j <= 5; j++)
 		{
-			m_scores[i-1].append(qMakePair(cfg.readEntry(QString("Score%1").arg(j),QVariant(0)).toInt(),cfg.readEntry(QString("Name%1").arg(j),QString())));
+			m_scores[i-1].append(qMakePair(cfg.readEntry(QStringLiteral("Score%1").arg(j),QVariant(0)).toInt(),cfg.readEntry(QStringLiteral("Name%1").arg(j),QString())));
 		}
 	}
 }
